Index: src/builtins/ia32/builtins-ia32.cc |
diff --git a/src/builtins/ia32/builtins-ia32.cc b/src/builtins/ia32/builtins-ia32.cc |
index 6e6af610917b2d94f34610654c038284a10e9970..50af4006c90c2db702998945404256b50e1d36d6 100644 |
--- a/src/builtins/ia32/builtins-ia32.cc |
+++ b/src/builtins/ia32/builtins-ia32.cc |
@@ -1058,17 +1058,17 @@ void Builtins::Generate_CompileLazy(MacroAssembler* masm) { |
__ mov(temp, FieldOperand(temp, WeakCell::kValueOffset)); |
__ cmp(temp, native_context); |
__ j(not_equal, &loop_bottom); |
- // Literals available? |
+ // Feedback vector available? |
__ mov(temp, FieldOperand(map, index, times_half_pointer_size, |
SharedFunctionInfo::kOffsetToPreviousLiterals)); |
__ mov(temp, FieldOperand(temp, WeakCell::kValueOffset)); |
__ JumpIfSmi(temp, &gotta_call_runtime); |
// Save the literals in the closure. |
__ mov(ecx, Operand(esp, 0)); |
- __ mov(FieldOperand(ecx, JSFunction::kLiteralsOffset), temp); |
+ __ mov(FieldOperand(ecx, JSFunction::kFeedbackVectorOffset), temp); |
__ push(index); |
- __ RecordWriteField(ecx, JSFunction::kLiteralsOffset, temp, index, |
+ __ RecordWriteField(ecx, JSFunction::kFeedbackVectorOffset, temp, index, |
kDontSaveFPRegs, EMIT_REMEMBERED_SET, OMIT_SMI_CHECK); |
__ pop(index); |
@@ -1058,17 +1058,17 @@ void Builtins::Generate_CompileLazy(MacroAssembler* masm) { |
__ mov(temp, FieldOperand(temp, WeakCell::kValueOffset)); |
__ JumpIfSmi(temp, &gotta_call_runtime); |
- // Save the literals in the closure. |
+ // Save the vector in the closure. |
__ mov(ecx, Operand(esp, 0)); |